aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMartin Willi <martin@strongswan.org>2007-03-20 08:14:18 +0000
committerMartin Willi <martin@strongswan.org>2007-03-20 08:14:18 +0000
commita1e5881c42d27883116f883f6c13289c4810cfeb (patch)
tree851dab4b515f9f70ffef1c24b51801bd016c1dfa
parent755bdcc274b064a0811985d3ec4112570515d422 (diff)
downloadstrongswan-a1e5881c42d27883116f883f6c13289c4810cfeb.tar.bz2
strongswan-a1e5881c42d27883116f883f6c13289c4810cfeb.tar.xz
renamed keyingtries attribute
-rw-r--r--src/charon/config/connections/connection.c14
-rw-r--r--src/charon/config/connections/connection.h9
2 files changed, 10 insertions, 13 deletions
diff --git a/src/charon/config/connections/connection.c b/src/charon/config/connections/connection.c
index 77f7ef82c..ffe508992 100644
--- a/src/charon/config/connections/connection.c
+++ b/src/charon/config/connections/connection.c
@@ -92,7 +92,7 @@ struct private_connection_t {
/**
* Number of retransmission sequences to send bevore giving up
*/
- u_int32_t retrans_sequences;
+ u_int32_t keyingtries;
/**
* Supported proposals
@@ -241,11 +241,11 @@ static u_int32_t get_dpd_delay(private_connection_t *this)
}
/**
- * Implementation of connection_t.get_retrans_seq.
+ * Implementation of connection_t.get_keyingtries.
*/
-static u_int32_t get_retrans_seq(private_connection_t *this)
+static u_int32_t get_keyingtries(private_connection_t *this)
{
- return this->retrans_sequences;
+ return this->keyingtries;
}
/**
@@ -357,7 +357,7 @@ connection_t * connection_create(char *name, bool ikev2,
cert_policy_t certreq_policy,
host_t *my_host, host_t *other_host,
u_int32_t dpd_delay, bool reauth,
- u_int32_t retrans_sequences,
+ u_int32_t keyingtries,
u_int32_t hard_lifetime,
u_int32_t soft_lifetime, u_int32_t jitter)
{
@@ -375,7 +375,7 @@ connection_t * connection_create(char *name, bool ikev2,
this->public.add_proposal = (void(*)(connection_t*, proposal_t*)) add_proposal;
this->public.get_dpd_delay = (u_int32_t(*)(connection_t*)) get_dpd_delay;
this->public.get_reauth = (bool(*)(connection_t*)) get_reauth;
- this->public.get_retrans_seq = (u_int32_t(*)(connection_t*)) get_retrans_seq;
+ this->public.get_keyingtries = (u_int32_t(*)(connection_t*)) get_keyingtries;
this->public.get_dh_group = (diffie_hellman_group_t(*)(connection_t*)) get_dh_group;
this->public.check_dh_group = (bool(*)(connection_t*,diffie_hellman_group_t)) check_dh_group;
this->public.get_soft_lifetime = (u_int32_t (*) (connection_t *))get_soft_lifetime;
@@ -393,7 +393,7 @@ connection_t * connection_create(char *name, bool ikev2,
this->other_host = other_host;
this->dpd_delay = dpd_delay;
this->reauth = reauth;
- this->retrans_sequences = retrans_sequences;
+ this->keyingtries = keyingtries;
this->hard_lifetime = hard_lifetime;
this->soft_lifetime = soft_lifetime;
this->jitter = jitter;
diff --git a/src/charon/config/connections/connection.h b/src/charon/config/connections/connection.h
index f90c2e99c..d0788876f 100644
--- a/src/charon/config/connections/connection.h
+++ b/src/charon/config/connections/connection.h
@@ -143,13 +143,10 @@ struct connection_t {
/**
* @brief Get the max number of retransmission sequences.
*
- * After this number of sequences, a not responding peer is considered
- * dead.
- *
* @param this calling object
* @return max number of retransmission sequences
*/
- u_int32_t (*get_retrans_seq) (connection_t *this);
+ u_int32_t (*get_keyingtries) (connection_t *this);
/**
* @brief Get the connection name.
@@ -276,7 +273,7 @@ struct connection_t {
* @param other_host host_t representing remote address
* @param dpd_delay interval of DPD liveness checks
* @param reauth use full reauthentication instead of rekeying
* @param retrans_sequences number of retransmit sequences to use
* @param hard_lifetime lifetime before deleting an IKE_SA
* @param soft_lifetime lifetime before rekeying an IKE_SA
* @param jitter range of randomization time
@@ -288,7 +285,7 @@ connection_t * connection_create(char *name, bool ikev2,
cert_policy_t cert_pol, cert_policy_t req_pol,
host_t *my_host, host_t *other_host,
u_int32_t dpd_delay, bool reauth,
- u_int32_t retrans_sequences,
+ u_int32_t keyingtries,
u_int32_t hard_lifetime, u_int32_t soft_lifetime,
u_int32_t jitter);
@@ -276,7 +273,7 @@ struct connection_t {
* @param dpd_delay interval of DPD liveness checks
* @param reauth use full reauthentication instead of rekeying
- * @param retrans_sequences number of retransmit sequences to use
+ * @param keyingtries number of retransmit sequences to use
* @param hard_lifetime lifetime before deleting an IKE_SA
* @param soft_lifetime lifetime before rekeying an IKE_SA